==> adminer-3.1.0.zip: adminer-3.1.0/adminer/lang/de.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Abmeldung erfolgreich.',
	'Invalid credentials.' => 'Ungültige Anmelde-Informationen.',
	'Server' => 'Server',
	'Username' => 'Benutzer',
	'Password' => 'Passwort',
	'Select database' => 'Datenbank auswählen',
	'Invalid database.' => 'Datenbank ungültig.',
	'Create new database' => 'Neue Datenbank',
	'Table has been dropped.' => 'Tabelle entfernt.',
	'Table has been altered.' => 'Tabelle geändert.',
	'Table has been created.' => 'Tabelle erstellt.',
	'Alter table' => 'Tabelle ändern',
	'Create table' => 'Neue Tabelle erstellen',
	'Table name' => 'Name der Tabelle',
	'engine' => 'Motor',
	'collation' => 'Kollation',
	'Column name' => 'Spaltenname',
	'Type' => 'Typ',
	'Length' => 'Länge',
	'Auto Increment' => 'Auto-Inkrement',
	'Options' => 'Optionen',
	'Save' => 'Speichern',
	'Drop' => 'Entfernen',
	'Database has been dropped.' => 'Datenbank entfernt.',
	'Database has been created.' => 'Datenbank erstellt.',
	'Database has been renamed.' => 'Datenbank umbenannt.',
	'Database has been altered.' => 'Datenbank geändert.',
	'Alter database' => 'Datenbank ändern',
	'Create database' => 'Neue Datenbank',
	'SQL command' => 'SQL-Query',
	'Dump' => 'Export',
	'Logout' => 'Abmelden',
	'database' => 'Datenbank',
	'Use' => 'Benutzung',
	'No tables.' => 'Keine Tabellen.',
	'select' => 'zeigen',
	'Create new table' => 'Neue Tabelle',
	'Item has been deleted.' => 'Datensatz gelöscht.',
	'Item has been updated.' => 'Datensatz geändert.',
	'Item%s has been inserted.' => 'Datensatz%s hinzugefügt.',
	'Edit' => 'Ändern',
	'Insert' => 'Hinzufügen',
	'Save and insert next' => 'Speichern und nächsten hinzufügen',
	'Delete' => 'Entfernen',
	'Database' => 'Datenbank',
	'Routines' => 'Prozeduren',
	'Indexes have been altered.' => 'Indizes geändert.',
	'Indexes' => 'Indizes',
	'Alter indexes' => 'Indizes ändern',
	'Add next' => 'Hinzufügen',
	'Language' => 'Sprache',
	'Select' => 'Daten zeigen von',
	'New item' => 'Neuer Datensatz',
	'Search' => 'Suchen',
	'Sort' => 'Ordnen',
	'descending' => 'absteigend',
	'Limit' => 'Begrenzung',
	'No rows.' => 'Keine Daten.',
	'Action' => 'Aktion',
	'edit' => 'ändern',
	'Page' => 'Seite',
	'Query executed OK, %d row(s) affected.' => array('Abfrage ausgeführt, %d Datensatz betroffen.', 'Abfrage ausgeführt, %d Datensätze betroffen.'),
	'Error in query' => 'Fehler in der SQL-Abfrage',
	'Execute' => 'Ausführen',
	'Table' => 'Tabelle',
	'Foreign keys' => 'Fremdschlüssel',
	'Triggers' => 'Trigger',
	'View' => 'View',
	'Unable to select the table' => 'Auswahl der Tabelle fehlgeschlagen',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token ungültig. Bitte die Formulardaten erneut abschicken.',
	'Comment' => 'Kommentar',
	'Default values' => 'Vorgabewerte festlegen',
	'%d byte(s)' => array('%d Byte', '%d Bytes'),
	'No commands to execute.' => 'Kein Kommando vorhanden.',
	'Unable to upload a file.' => 'Hochladen von Datei fehlgeschlagen.',
	'File upload' => 'Datei importieren',
	'File uploads are disabled.' => 'Importieren von Dateien abgeschaltet.',
	'Routine has been called, %d row(s) affected.' => array('Kommando SQL ausgeführt, %d Datensatz betroffen.', 'Kommando SQL ausgeführt, %d Datensätze betroffen.'),
	'Call' => 'Aufrufen',
	'No extension' => 'Keine Erweiterungen installiert',
	'None of the supported PHP extensions (%s) are available.' => 'Keine der unterstützten PHP-Erweiterungen (%s) ist vorhanden.',
	'Session support must be enabled.' => 'Sitzungen müssen aktiviert sein.',
	'Session expired, please login again.' => 'Sitzungsdauer abgelaufen, bitte erneut anmelden.',
	'Text length' => 'Textlänge',
	'Foreign key has been dropped.' => 'Fremdschlüssel entfernt.',
	'Foreign key has been altered.' => 'Fremdschlüssel geändert.',
	'Foreign key has been created.' => 'Fremdschlüssel erstellt.',
	'Foreign key' => 'Fremdschlüssel',
	'Target table' => 'Zieltabelle',
	'Change' => 'Ändern',
	'Source' => 'Ursprung',
	'Target' => 'Ziel',
	'Add column' => 'Spalte hinzufügen',
	'Alter' => 'Ändern',
	'Add foreign key' => 'Fremdschlüssel hinzufügen',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index-Typ',
	'Column (length)' => 'Spalte (Länge)',
	'View has been dropped.' => 'View entfernt.',
	'View has been altered.' => 'View geändert.',
	'View has been created.' => 'View erstellt.',
	'Alter view' => 'View ändern',
	'Create view' => 'Neue View erstellen',
	'Name' => 'Name',
	'Process list' => 'Prozessliste',
	'%d process(es) have been killed.' => array('%d Prozess gestoppt.', '%d Prozesse gestoppt.'),
	'Kill' => 'Anhalten',
	'Parameter name' => 'Name des Parameters',
	'Database schema' => 'Datenbankschema',
	'Create procedure' => 'Neue Prozedur',
	'Create function' => 'Neue Funktion',
	'Routine has been dropped.' => 'Prozedur entfernt.',
	'Routine has been altered.' => 'Prozedur geändert.',
	'Routine has been created.' => 'Prozedur erstellt.',
	'Alter function' => 'Funktion ändern',
	'Alter procedure' => 'Prozedur ändern',
	'Return type' => 'Typ des Rückgabewertes',
	'Add trigger' => 'Trigger hinzufügen',
	'Trigger has been dropped.' => 'Trigger entfernt.',
	'Trigger has been altered.' => 'Trigger geändert.',
	'Trigger has been created.' => 'Trigger erstellt.',
	'Alter trigger' => 'Trigger ändern',
	'Create trigger' => 'Trigger hinzufügen',
	'Time' => 'Zeitpunkt',
	'Event' => 'Ereignis',
	'%s version: %s through PHP extension %s' => 'Version %s: %s, mit PHP-Erweiterung %s',
	'%d row(s)' => array('%d Datensatz', '%d Datensätze'),
	'Remove' => 'Entfernen',
	'Are you sure?' => 'Sind Sie sicher ?',
	'Privileges' => 'Rechte',
	'Create user' => 'Neuer Benutzer',
	'User has been dropped.' => 'Benutzer entfernt.',
	'User has been altered.' => 'Benutzer geändert.',
	'User has been created.' => 'Benutzer erstellt.',
	'Hashed' => 'Hashed',
	'Column' => 'Spalte',
	'Routine' => 'Rutine',
	'Grant' => 'Erlauben',
	'Revoke' => 'Verbieten',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data zu gross. Reduzieren Sie die Grösse oder vergrössern Sie den Wert %s in der Konfiguration.',
	'Logged as: %s' => 'Angemeldet als: %s',
	'Move up' => 'Nach oben',
	'Move down' => 'Nach unten',
	'Functions' => 'Funktionen',
	'Aggregation' => 'Agregationen',
	'Export' => 'Exportieren',
	'Output' => 'Ergebnis',
	'open' => 'anzeigen',
	'save' => 'Datei',
	'Format' => 'Format',
	'Tables' => 'Tabellen',
	'Data' => 'Daten',
	'Event has been dropped.' => 'Ereignis entfernt.',
	'Event has been altered.' => 'Ereignis geändert.',
	'Event has been created.' => 'Ereignis erstellt.',
	'Alter event' => 'Ereignis ändern',
	'Create event' => 'Ereignis erstellen',
	'At given time' => 'Zur angegebenen Zeit',
	'Every' => 'Jede',
	'Events' => 'Ereignisse',
	'Schedule' => 'Zeitplan',
	'Start' => 'Start',
	'End' => 'Ende',
	'Status' => 'Status',
	'On completion preserve' => 'Nach der Ausführung erhalten',
	'Tables and views' => 'Tabellen und Views',
	'Data Length' => 'Datengrösse',
	'Index Length' => 'Indexgrösse',
	'Data Free' => 'Freier Bereich',
	'Collation' => 'Collation',
	'Analyze' => 'Analysieren',
	'Optimize' => 'Optimieren',
	'Check' => 'Prüfen',
	'Repair' => 'Reparieren',
	'Truncate' => 'Entleeren (truncate)',
	'Tables have been truncated.' => 'Tabellen sind entleert worden (truncate).',
	'Rows' => 'Datensätze',
	',' => ' ',
	'Tables have been moved.' => 'Tabellen verschoben.',
	'Move to other database' => 'In andere Datenbank verschieben',
	'Move' => 'Verschieben',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Speichern und weiter bearbeiten',
	'original' => 'Original',
	'Tables have been dropped.' => 'Tabellen wurden entfernt (drop).',
	'%d item(s) have been affected.' => array('%d Artikel betroffen.', '%d Artikel betroffen.'),
	'whole result' => 'Gesamtergebnis',
	'Clone' => 'Klonen',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Die maximal erlaubte Anzahl der Felder ist überschritten. Bitte %s und %s erhöhen.',
	'Partition by' => 'Partitionieren um',
	'Partitions' => 'Partitionen',
	'Partition name' => 'Name der Partition',
	'Values' => 'Werte',
	'%d row(s) have been imported.' => array('%d Datensatz importiert.', '%d Datensätze wurden importiert.'),
	'anywhere' => 'beliebig',
	'CSV Import' => 'Importiere CSV',
	'Import' => 'Importieren',
	'Stop on error' => 'Bei Fehler anhalten',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 't.m.[jjjj]',
	'History' => 'History',
	'Variables' => 'Variablen',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Spalten des Ursprungs und des Zieles müssen vom gleichen Datentyp sein, es muss unter den Zielspalten ein Index existieren und die referenzierten Daten müssen existieren.',
	'Relations' => 'Relationen',
	'Run file' => 'Datei ausführen',
	'Clear' => 'Entleeren',
	'Maximum allowed file size is %sB.' => 'Maximal erlaubte Dateigrösse ist %sB.',
	'Numbers' => 'Zahlen',
	'Date and time' => 'Datum oder Zeit',
	'Strings' => 'Zeichenketten',
	'Binary' => 'Binär',
	'Lists' => 'Listen',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'Von',
	'Subject' => 'Betreff',
	'Send' => 'Abschicken',
	'%d e-mail(s) have been sent.' => array('%d e-mail abgeschickt.', '%d e-mails abgeschickt.'),
	'Webserver file %s' => 'Webserver Datei %s',
	'File does not exist.' => 'Datei existiert nicht.',
	'%d in total' => '%d insgesamt',
	'Permanent login' => 'Passwort speichern',
	'Databases have been dropped.' => 'Datenbanken entfernt.',
	'Search data in tables' => 'Suche in Tabellen',
	'schema' => 'Schema',
	'Schema' => 'Schema',
	'Alter schema' => 'Schema ändern',
	'Create schema' => 'Neues Schema',
	'Schema has been dropped.' => 'Schema wurde gelöscht.',
	'Schema has been created.' => 'Neues Schema erstellt.',
	'Schema has been altered.' => 'Schema geändert.',
	'Sequences' => 'Sequenz',
	'Create sequence' => 'Neue Sequenz',
	'Alter sequence' => 'Sequenz ändern',
	'Sequence has been dropped.' => 'Sequenz gelöscht.',
	'Sequence has been created.' => 'Neue Sequenz erstellt.',
	'Sequence has been altered.' => 'Sequenz geändert.',
	'User types' => 'Benutzer-definierte Typen',
	'Create type' => 'Typ erstellen',
	'Alter type' => 'Typ ändern',
	'Type has been dropped.' => 'Typ gelöscht.',
	'Type has been created.' => 'Typ erstellt.',
	'Double click on a value to modify it.' => 'Doppelklick zum Bearbeiten des Wertes.',
	'Increase Text length to modify this value.' => 'Vergrössern Sie die Textlänge um den Wert ändern zu können.',
	'Use edit link to modify this value.' => 'Benutzen Sie den Link zum editieren dieses Wertes.',
	'last' => 'letzte',
	'From server' => 'Auf Server',
	'System' => 'Datenbank System',
	'Select data' => 'Daten auswählen',
	'Show structure' => 'Struktur anzeigen',
	'empty' => 'leer',
	'Network' => 'Netzwerk',
	'Geometry' => 'Geometrie',
	'File exists.' => 'Datei existiert schon.',
	'Attachments' => 'Anhänge',
	'%d query(s) executed OK.' => array('SQL-Query erfolgreich ausgeführt.', '%d SQL-Queries erfolgreich ausgeführt.'),
	'Show only errors' => 'Nur Fehler anzeigen',
	'Last page' => 'Letzte Seite',
	'Refresh' => 'Aktualisieren',
	'Invalid schema.' => 'Schema nicht gültig.',
	'Please use one of the extensions %s.' => 'Bitte einen der Dateitypen %s benutzen.',
	'now' => 'jetzt',
	'ltr' => 'ltr',
);

==> adminer-3.2.1.zip: adminer-3.2.1/adminer/lang/de.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Abmeldung erfolgreich.',
	'Invalid credentials.' => 'Ungültige Anmelde-Informationen.',
	'Server' => 'Server',
	'Username' => 'Benutzer',
	'Password' => 'Passwort',
	'Select database' => 'Datenbank auswählen',
	'Invalid database.' => 'Datenbank ungültig.',
	'Create new database' => 'Neue Datenbank',
	'Table has been dropped.' => 'Tabelle entfernt.',
	'Table has been altered.' => 'Tabelle geändert.',
	'Table has been created.' => 'Tabelle erstellt.',
	'Alter table' => 'Tabelle ändern',
	'Create table' => 'Neue Tabelle erstellen',
	'Table name' => 'Name der Tabelle',
	'engine' => 'Motor',
	'collation' => 'Kollation',
	'Column name' => 'Spaltenname',
	'Type' => 'Typ',
	'Length' => 'Länge',
	'Auto Increment' => 'Auto-Inkrement',
	'Options' => 'Optionen',
	'Save' => 'Speichern',
	'Drop' => 'Entfernen',
	'Database has been dropped.' => 'Datenbank entfernt.',
	'Database has been created.' => 'Datenbank erstellt.',
	'Database has been renamed.' => 'Datenbank umbenannt.',
	'Database has been altered.' => 'Datenbank geändert.',
	'Alter database' => 'Datenbank ändern',
	'Create database' => 'Neue Datenbank',
	'SQL command' => 'SQL-Query',
	'Dump' => 'Export',
	'Logout' => 'Abmelden',
	'database' => 'Datenbank',
	'Use' => 'Benutzung',
	'No tables.' => 'Keine Tabellen.',
	'select' => 'zeigen',
	'Create new table' => 'Neue Tabelle',
	'Item has been deleted.' => 'Datensatz gelöscht.',
	'Item has been updated.' => 'Datensatz geändert.',
	'Item%s has been inserted.' => 'Datensatz%s hinzugefügt.',
	'Edit' => 'Ändern',
	'Insert' => 'Hinzufügen',
	'Save and insert next' => 'Speichern und nächsten hinzufügen',
	'Delete' => 'Entfernen',
	'Database' => 'Datenbank',
	'Routines' => 'Prozeduren',
	'Indexes have been altered.' => 'Indizes geändert.',
	'Indexes' => 'Indizes',
	'Alter indexes' => 'Indizes ändern',
	'Add next' => 'Hinzufügen',
	'Language' => 'Sprache',
	'Select' => 'Daten zeigen von',
	'New item' => 'Neuer Datensatz',
	'Search' => 'Suchen',
	'Sort' => 'Ordnen',
	'descending' => 'absteigend',
	'Limit' => 'Begrenzung',
	'No rows.' => 'Keine Daten.',
	'Action' => 'Aktion',
	'edit' => 'ändern',
	'Page' => 'Seite',
	'Query executed OK, %d row(s) affected.' => array('Abfrage ausgeführt, %d Datensatz betroffen.', 'Abfrage ausgeführt, %d Datensätze betroffen.'),
	'Error in query' => 'Fehler in der SQL-Abfrage',
	'Execute' => 'Ausführen',
	'Table' => 'Tabelle',
	'Foreign keys' => 'Fremdschlüssel',
	'Triggers' => 'Trigger',
	'View' => 'View',
	'Unable to select the table' => 'Auswahl der Tabelle fehlgeschlagen',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token ungültig. Bitte die Formulardaten erneut abschicken.',
	'Comment' => 'Kommentar',
	'Default values' => 'Vorgabewerte festlegen',
	'%d byte(s)' => array('%d Byte', '%d Bytes'),
	'No commands to execute.' => 'Kein Kommando vorhanden.',
	'Unable to upload a file.' => 'Hochladen von Datei fehlgeschlagen.',
	'File upload' => 'Datei importieren',
	'File uploads are disabled.' => 'Importieren von Dateien abgeschaltet.',
	'Routine has been called, %d row(s) affected.' => array('Kommando SQL ausgeführt, %d Datensatz betroffen.', 'Kommando SQL ausgeführt, %d Datensätze betroffen.'),
	'Call' => 'Aufrufen',
	'No extension' => 'Keine Erweiterungen installiert',
	'None of the supported PHP extensions (%s) are available.' => 'Keine der unterstützten PHP-Erweiterungen (%s) ist vorhanden.',
	'Session support must be enabled.' => 'Sitzungen müssen aktiviert sein.',
	'Session expired, please login again.' => 'Sitzungsdauer abgelaufen, bitte erneut anmelden.',
	'Text length' => 'Textlänge',
	'Foreign key has been dropped.' => 'Fremdschlüssel entfernt.',
	'Foreign key has been altered.' => 'Fremdschlüssel geändert.',
	'Foreign key has been created.' => 'Fremdschlüssel erstellt.',
	'Foreign key' => 'Fremdschlüssel',
	'Target table' => 'Zieltabelle',
	'Change' => 'Ändern',
	'Source' => 'Ursprung',
	'Target' => 'Ziel',
	'Add column' => 'Spalte hinzufügen',
	'Alter' => 'Ändern',
	'Add foreign key' => 'Fremdschlüssel hinzufügen',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index-Typ',
	'Column (length)' => 'Spalte (Länge)',
	'View has been dropped.' => 'View entfernt.',
	'View has been altered.' => 'View geändert.',
	'View has been created.' => 'View erstellt.',
	'Alter view' => 'View ändern',
	'Create view' => 'Neue View erstellen',
	'Name' => 'Name',
	'Process list' => 'Prozessliste',
	'%d process(es) have been killed.' => array('%d Prozess gestoppt.', '%d Prozesse gestoppt.'),
	'Kill' => 'Anhalten',
	'Parameter name' => 'Name des Parameters',
	'Database schema' => 'Datenbankschema',
	'Create procedure' => 'Neue Prozedur',
	'Create function' => 'Neue Funktion',
	'Routine has been dropped.' => 'Prozedur entfernt.',
	'Routine has been altered.' => 'Prozedur geändert.',
	'Routine has been created.' => 'Prozedur erstellt.',
	'Alter function' => 'Funktion ändern',
	'Alter procedure' => 'Prozedur ändern',
	'Return type' => 'Typ des Rückgabewertes',
	'Add trigger' => 'Trigger hinzufügen',
	'Trigger has been dropped.' => 'Trigger entfernt.',
	'Trigger has been altered.' => 'Trigger geändert.',
	'Trigger has been created.' => 'Trigger erstellt.',
	'Alter trigger' => 'Trigger ändern',
	'Create trigger' => 'Trigger hinzufügen',
	'Time' => 'Zeitpunkt',
	'Event' => 'Ereignis',
	'%s version: %s through PHP extension %s' => 'Version %s: %s, mit PHP-Erweiterung %s',
	'%d row(s)' => array('%d Datensatz', '%d Datensätze'),
	'Remove' => 'Entfernen',
	'Are you sure?' => 'Sind Sie sicher ?',
	'Privileges' => 'Rechte',
	'Create user' => 'Neuer Benutzer',
	'User has been dropped.' => 'Benutzer entfernt.',
	'User has been altered.' => 'Benutzer geändert.',
	'User has been created.' => 'Benutzer erstellt.',
	'Hashed' => 'Hashed',
	'Column' => 'Spalte',
	'Routine' => 'Rutine',
	'Grant' => 'Erlauben',
	'Revoke' => 'Verbieten',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data zu gross. Reduzieren Sie die Grösse oder vergrössern Sie den Wert %s in der Konfiguration.',
	'Logged as: %s' => 'Angemeldet als: %s',
	'Move up' => 'Nach oben',
	'Move down' => 'Nach unten',
	'Functions' => 'Funktionen',
	'Aggregation' => 'Agregationen',
	'Export' => 'Exportieren',
	'Output' => 'Ergebnis',
	'open' => 'anzeigen',
	'save' => 'Datei',
	'Format' => 'Format',
	'Tables' => 'Tabellen',
	'Data' => 'Daten',
	'Event has been dropped.' => 'Ereignis entfernt.',
	'Event has been altered.' => 'Ereignis geändert.',
	'Event has been created.' => 'Ereignis erstellt.',
	'Alter event' => 'Ereignis ändern',
	'Create event' => 'Ereignis erstellen',
	'At given time' => 'Zur angegebenen Zeit',
	'Every' => 'Jede',
	'Events' => 'Ereignisse',
	'Schedule' => 'Zeitplan',
	'Start' => 'Start',
	'End' => 'Ende',
	'Status' => 'Status',
	'On completion preserve' => 'Nach der Ausführung erhalten',
	'Tables and views' => 'Tabellen und Views',
	'Data Length' => 'Datengrösse',
	'Index Length' => 'Indexgrösse',
	'Data Free' => 'Freier Bereich',
	'Collation' => 'Collation',
	'Analyze' => 'Analysieren',
	'Optimize' => 'Optimieren',
	'Check' => 'Prüfen',
	'Repair' => 'Reparieren',
	'Truncate' => 'Entleeren (truncate)',
	'Tables have been truncated.' => 'Tabellen sind entleert worden (truncate).',
	'Rows' => 'Datensätze',
	',' => ' ',
	'Tables have been moved.' => 'Tabellen verschoben.',
	'Move to other database' => 'In andere Datenbank verschieben',
	'Move' => 'Verschieben',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Speichern und weiter bearbeiten',
	'original' => 'Original',
	'Tables have been dropped.' => 'Tabellen wurden entfernt (drop).',
	'%d item(s) have been affected.' => '%d Artikel betroffen.',
	'whole result' => 'Gesamtergebnis',
	'Clone' => 'Klonen',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Die maximal erlaubte Anzahl der Felder ist überschritten. Bitte %s und %s erhöhen.',
	'Partition by' => 'Partitionieren um',
	'Partitions' => 'Partitionen',
	'Partition name' => 'Name der Partition',
	'Values' => 'Werte',
	'%d row(s) have been imported.' => array('%d Datensatz importiert.', '%d Datensätze wurden importiert.'),
	'anywhere' => 'beliebig',
	'Import' => 'Importieren',
	'Stop on error' => 'Bei Fehler anhalten',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 't.m.[jjjj]',
	'History' => 'History',
	'Variables' => 'Variablen',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Spalten des Ursprungs und des Zieles müssen vom gleichen Datentyp sein, es muss unter den Zielspalten ein Index existieren und die referenzierten Daten müssen existieren.',
	'Relations' => 'Relationen',
	'Run file' => 'Datei ausführen',
	'Clear' => 'Entleeren',
	'Maximum allowed file size is %sB.' => 'Maximal erlaubte Dateigrösse ist %sB.',
	'Numbers' => 'Zahlen',
	'Date and time' => 'Datum oder Zeit',
	'Strings' => 'Zeichenketten',
	'Binary' => 'Binär',
	'Lists' => 'Listen',
	'Editor' => 'Editor',
	'E-mail' => 'E-mail',
	'From' => 'Von',
	'Subject' => 'Betreff',
	'Send' => 'Abschicken',
	'%d e-mail(s) have been sent.' => array('%d e-mail abgeschickt.', '%d e-mails abgeschickt.'),
	'Webserver file %s' => 'Webserver Datei %s',
	'File does not exist.' => 'Datei existiert nicht.',
	'%d in total' => '%d insgesamt',
	'Permanent login' => 'Passwort speichern',
	'Databases have been dropped.' => 'Datenbanken entfernt.',
	'Search data in tables' => 'Suche in Tabellen',
	'schema' => 'Schema',
	'Schema' => 'Schema',
	'Alter schema' => 'Schema ändern',
	'Create schema' => 'Neues Schema',
	'Schema has been dropped.' => 'Schema wurde gelöscht.',
	'Schema has been created.' => 'Neues Schema erstellt.',
	'Schema has been altered.' => 'Schema geändert.',
	'Sequences' => 'Sequenz',
	'Create sequence' => 'Neue Sequenz',
	'Alter sequence' => 'Sequenz ändern',
	'Sequence has been dropped.' => 'Sequenz gelöscht.',
	'Sequence has been created.' => 'Neue Sequenz erstellt.',
	'Sequence has been altered.' => 'Sequenz geändert.',
	'User types' => 'Benutzer-definierte Typen',
	'Create type' => 'Typ erstellen',
	'Alter type' => 'Typ ändern',
	'Type has been dropped.' => 'Typ gelöscht.',
	'Type has been created.' => 'Typ erstellt.',
	'Double click on a value to modify it.' => 'Doppelklick zum Bearbeiten des Wertes.',
	'Use edit link to modify this value.' => 'Benutzen Sie den Link zum editieren dieses Wertes.',
	'last' => 'letzte',
	'From server' => 'Auf Server',
	'System' => 'Datenbank System',
	'Select data' => 'Daten auswählen',
	'Show structure' => 'Struktur anzeigen',
	'empty' => 'leer',
	'Network' => 'Netzwerk',
	'Geometry' => 'Geometrie',
	'File exists.' => 'Datei existiert schon.',
	'Attachments' => 'Anhänge',
	'%d query(s) executed OK.' => array('SQL-Query erfolgreich ausgeführt.', '%d SQL-Queries erfolgreich ausgeführt.'),
	'Show only errors' => 'Nur Fehler anzeigen',
	'Last page' => 'Letzte Seite',
	'Refresh' => 'Aktualisieren',
	'Invalid schema.' => 'Schema nicht gültig.',
	'Please use one of the extensions %s.' => 'Bitte einen der Dateitypen %s benutzen.',
	'now' => 'jetzt',
	'ltr' => 'ltr',
);
